@@ -20,6 +20,7 @@ pub(crate) enum Flag {
     Next,
     Eof,
 }
+
 /// IO State
 pub struct State<T> {
     io: T,
@@ -173,12 +174,11 @@ impl<T> State<T> {
                     self.flag = Flag::Next;
                     self.buffer.advance(self.delimiter.len());
                     return None;
-                } else {
-                    // prev part last data
-                    let buf = self.buffer.split_to(*n).freeze();
-                    *n = 0;
-                    return Some(buf);
                 }
+                // prev part last data
+                let buf = self.buffer.split_to(*n).freeze();
+                *n = 0;
+                return Some(buf);
             }
         }
 
@@ -225,6 +225,6 @@ impl<T> fmt::Debug for State<T> {
             .field("limits", &self.limits)
             .field("is_readable", &self.is_readable)
             .field("boundary", &String::from_utf8_lossy(self.boundary()))
-            .finish()
+            .finish_non_exhaustive()
     }
 }
